package LATMOS::Accounts::Web::Controller::Json::Timeline;
use Moose;
use namespace::autoclean;

use DateTime;
use Date::Parse;

BEGIN { extends 'Catalyst::Controller'; }

=head1 NAME

LATMOS::Accounts::Web::Controller::Json::Timeline - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=cut


=head2 index

=cut

sub index :Path :Args(1) {
    my ( $self, $c, $user ) = @_;

    my $base = $c->model('Accounts')->db;
    my $ouser = $base->get_object('user', $user)
        or return;

    my @colors = qw(black silver green blue red);
    my %colorset;


    my $var = {
        start => $ouser->get_attributes('create'),
        end => undef,
        employments => {
            name => 'Employment',
            color => '#000000',
            spans => [],
            events => [],
        },
    };

    foreach my $emp ($ouser->listEmployment) {
        my $employment = $base->get_object('employment', $emp);

        my $vemp = {
            name => ($employment->get_attributes('contratType') || ''),
            start => $employment->get_attributes('firstday'),
            end => $employment->get_attributes('lastday') || undef,
        };

        if (!$colorset{$vemp->{name}}) {
            $colorset{$vemp->{name}} = $colors[0];
            push(@colors, shift(@colors));
        }
        $vemp->{color} =  $colorset{$vemp->{name}};

        if (!$vemp->{end}) {
            my $time = str2time($vemp->{start});
            my $dt = DateTime->from_epoch(epoch => $time);
            $dt->add(days => 3 * 365);
            $vemp->{end} = $dt->ymd('-');
        }

        $var->{end}   = $vemp->{end}   if ((!$var->{end}) || $vemp->{end} gt $var->{end});
        $var->{start} = $vemp->{start} if ($vemp->{start} lt $var->{start});

        push(@{$var->{employments}{spans}}, $vemp);

        push(@{$var->{employments}{events}}, {
                name => 'Today',
                date => DateTime->now->ymd('-'),
        });
        if (my $expire = $ouser->get_attributes('expire')) {
            push(@{$var->{employments}{events}}, {
                    name => 'Expire',
                    date => $expire,
            });
        }
    }

    $c->stash->{data} = $var;
}



=encoding utf8

=head1 AUTHOR

Olivier Thauvin,Guyancourt - B1428,+33 1 80285052,

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
